@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteapp.c,v 1.75 2006/02/10 09:25:56 behdad Exp $"
 
 #include "../config.h"
 
@@ -34,13 +33,7 @@
 #include "debug.h"
 #include "vte.h"
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext(PACKAGE, String)
-#else
-#define _(String) String
-#define bindtextdomain(package,dir)
-#endif
+#include <glib/gi18n-lib.h>
 
 #define DINGUS1 "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?"
 #define DINGUS2 "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#\\%]*[^]'\\.}>\\) ,\\\"]"
@@ -374,12 +367,8 @@ take_xconsole_ownership(GtkWidget *widget, gpointer data)
 
 	name = g_strdup_printf("MIT_CONSOLE_%s", hostname);
 	atom = gdk_atom_intern(name, FALSE);
-#if GTK_CHECK_VERSION(2,2,0)
 	clipboard = gtk_clipboard_get_for_display(gtk_widget_get_display(widget),
 						  atom);
-#else
-	clipboard = gtk_clipboard_get(atom);
-#endif
 	g_free(name);
 
 	gtk_clipboard_set_with_owner(clipboard,
@@ -399,8 +388,14 @@ add_weak_pointer(GObject *object, GtkWidget **target)
 int
 main(int argc, char **argv)
 {
+	GdkScreen *screen;
+	GdkColormap *colormap;
 	GtkWidget *window, *hbox, *scrollbar, *widget;
-	char *env_add[] = {"FOO=BAR", "BOO=BIZ", NULL};
+	char *env_add[] = {
+#ifdef VTE_DEBUG
+		"FOO=BAR", "BOO=BIZ",
+#endif
+		NULL};
 	const char *background = NULL;
 	gboolean transparent = FALSE, audible = TRUE, blink = TRUE,
 		 debug = FALSE, dingus = FALSE, geometry = TRUE, dbuffer = TRUE,
@@ -574,6 +569,12 @@ main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(window), "delete_event",
 			 GTK_SIGNAL_FUNC(deleted_and_quit), window);
 
+	/* Set ARGB colormap */
+	screen = gtk_widget_get_screen (window);
+	colormap = gdk_screen_get_rgba_colormap (screen);
+	if (colormap)
+	    gtk_widget_set_colormap(GTK_WIDGET (window), colormap);
+
 	/* Create a box to hold everything. */
 	hbox = gtk_hbox_new(0, FALSE);
 	gtk_container_add(GTK_CONTAINER(window), hbox);
@@ -665,6 +666,7 @@ main(int argc, char **argv)
 	}
 	vte_terminal_set_background_tint_color(VTE_TERMINAL(widget), &tint);
 	vte_terminal_set_colors(VTE_TERMINAL(widget), &fore, &back, NULL, 0);
+	vte_terminal_set_opacity(VTE_TERMINAL(widget), 0xcccc);
 	if (highlight_set) {
 		vte_terminal_set_color_highlight(VTE_TERMINAL(widget),
 						 &highlight);
@@ -752,10 +754,12 @@ main(int argc, char **argv)
 						  command, NULL, env_add,
 						  working_directory,
 						  TRUE, TRUE, TRUE);
+	#ifdef VTE_DEBUG
 			if (command == NULL) {
 				vte_terminal_feed_child(VTE_TERMINAL(widget),
 							"pwd\n", -1);
 			}
+	#endif
 		} else {
 			long i;
 			i = vte_terminal_forkpty(VTE_TERMINAL(widget),
