@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vtexft.c,v 1.23 2006/01/15 21:09:41 gpastore Exp $"
 
 #include "../config.h"
 
@@ -37,21 +36,13 @@
 #include "vtexft.h"
 #include "vtetree.h"
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext(PACKAGE, String)
-#else
-#define _(String) String
-#define bindtextdomain(package,dir)
-#endif
+#include <glib/gi18n-lib.h>
 
 #define FONT_INDEX_FUDGE 10
 #define CHAR_WIDTH_FUDGE 10
 
 struct _vte_xft_font {
-#if GTK_CHECK_VERSION(2,2,0)
 	GdkDisplay *display;
-#endif
 	GArray *patterns;
 	GArray *fonts;
 	VteTree *fontmap;
@@ -69,6 +60,7 @@ struct _vte_xft_data
 	XftDraw *draw;
 	GC gc;
 	GdkColor color;
+	guint16 opacity;
 	GdkPixmap *pixmap;
 	Pixmap xpixmap;
 	gint pixmapw, pixmaph;
@@ -84,25 +76,17 @@ _vte_xft_direct_compare(gconstpointer a, gconstpointer b)
 static gboolean
 _vte_xft_char_exists(struct _vte_xft_font *font, XftFont *ftfont, FcChar32 c)
 {
-#if GTK_CHECK_VERSION(2,2,0)
 	return XftCharExists(GDK_DISPLAY_XDISPLAY(font->display),
 			     ftfont,
 			     c) == FcTrue;
-#else
-	return XftCharExists(GDK_DISPLAY(), ftfont, c) == FcTrue;
-#endif
 }
 
 static void
 _vte_xft_text_extents(struct _vte_xft_font *font, XftFont *ftfont, FcChar32 c,
 		      XGlyphInfo *extents)
 {
-#if GTK_CHECK_VERSION(2,2,0)
 	XftTextExtents32(GDK_DISPLAY_XDISPLAY(font->display),
 				ftfont, &c, 1, extents);
-#else
-	XftTextExtents32(GDK_DISPLAY(), ftfont, &c, 1, extents);
-#endif
 }
 
 static struct _vte_xft_font *
@@ -119,10 +103,8 @@ _vte_xft_font_open(GtkWidget *widget, const PangoFontDescription *fontdesc,
 		return NULL;
 	}
 
-	font = g_malloc0(sizeof(struct _vte_xft_font));
-#if GTK_CHECK_VERSION(2,2,0)
+	font = g_slice_new0(struct _vte_xft_font);
 	font->display = gtk_widget_get_display(widget);
-#endif
 	font->patterns = patterns;
 	font->fonts = g_array_new(TRUE, TRUE, sizeof(XftFont*));
 	font->fontmap = _vte_tree_new(_vte_xft_direct_compare);
@@ -172,7 +154,7 @@ _vte_xft_font_close(struct _vte_xft_font *font)
 	_vte_tree_destroy(font->widths);
 	font->widths = NULL;
 
-	g_free(font);
+	g_slice_free(struct _vte_xft_font, font);
 }
 
 static XftFont *
@@ -241,25 +223,15 @@ _vte_xft_font_for_char(struct _vte_xft_font *font, gunichar c)
 	for (i = font->fonts->len; i < font->patterns->len; i++) {
 		patternp = &g_array_index(font->patterns, FcPattern *, i);
 		ftfont = XftFontOpenPattern(display, *patternp);
-                
 		/* If the font was opened, it owns the pattern. */
 		if (ftfont != NULL) {
 			*patternp = NULL;
-                
-                        if (_vte_xft_char_exists(font, ftfont, c)) {
-                                g_array_append_val(font->fonts, ftfont);
-                                break;
-                        }
-
-                        /* To save memory, close fonts that don't match the pattern */
-                        XftFontClose(display, ftfont);
-                        ftfont = NULL;
-                }
-
-                /* The patterns array must match up with the fonts array, even if
-                 * that means appending a NULL to it.
-                 */
-                g_array_append_val(font->fonts, ftfont);
+		}
+		g_array_append_val(font->fonts, ftfont);
+		if ((ftfont != NULL) &&
+		    (_vte_xft_char_exists(font, ftfont, c))) {
+			break;
+		}
 	}
 
 	/* No match? */
@@ -332,7 +304,7 @@ static void
 _vte_xft_create(struct _vte_draw *draw, GtkWidget *widget)
 {
 	struct _vte_xft_data *data;
-	data = (struct _vte_xft_data*) g_malloc0(sizeof(struct _vte_xft_data));
+	data = g_slice_new0(struct _vte_xft_data);
 	draw->impl_data = data;
 	data->font = NULL;
 	data->display = NULL;
@@ -342,6 +314,7 @@ _vte_xft_create(struct _vte_draw *draw, GtkWidget *widget)
 	data->draw = NULL;
 	data->gc = NULL;
 	memset(&data->color, 0, sizeof(data->color));
+	data->opacity = 0xffff;
 	data->pixmap = NULL;
 	data->xpixmap = -1;
 	data->pixmapw = data->pixmaph = -1;
@@ -379,7 +352,7 @@ _vte_xft_destroy(struct _vte_draw *draw)
 	data->xpixmap = -1;
 	data->pixmapw = data->pixmaph = -1;
 	data->scrollx = data->scrolly = 0;
-	g_free(data);
+	g_slice_free(struct _vte_xft_data, data);
 }
 
 static GdkVisual *
@@ -445,11 +418,13 @@ _vte_xft_end(struct _vte_draw *draw)
 }
 
 static void
-_vte_xft_set_background_color(struct _vte_draw *draw, GdkColor *color)
+_vte_xft_set_background_color(struct _vte_draw *draw, GdkColor *color,
+			      guint16 opacity)
 {
 	struct _vte_xft_data *data;
 	data = (struct _vte_xft_data*) draw->impl_data;
 	data->color = *color;
+	data->opacity = opacity;
 }
 
 static void
@@ -462,12 +437,15 @@ _vte_xft_set_background_image(struct _vte_draw *draw,
 {
 	struct _vte_xft_data *data;
 	GdkPixmap *pixmap;
+	GdkScreen *screen;
 
 	data = (struct _vte_xft_data*) draw->impl_data;
 
+	screen = gtk_widget_get_screen (draw->widget);
+
 	data->xpixmap = -1;
 	data->pixmapw = data->pixmaph = 0;
-	pixmap = vte_bg_get_pixmap(vte_bg_get(), type,
+	pixmap = vte_bg_get_pixmap(vte_bg_get_for_screen(screen), type,
 				   pixbuf, file, color, saturation,
 				   _vte_draw_get_colormap(draw, TRUE));
 	if (GDK_IS_PIXMAP(data->pixmap)) {
@@ -495,10 +473,10 @@ _vte_xft_clear(struct _vte_draw *draw,
 	if (!GDK_IS_PIXMAP(data->pixmap) ||
 	    (data->pixmapw <= 0) ||
 	    (data->pixmaph <= 0)) {
-		rcolor.red = data->color.red;
-		rcolor.green = data->color.green;
-		rcolor.blue = data->color.blue;
-		rcolor.alpha = 0xffff;
+		rcolor.red = data->color.red * data->opacity / 0xffff;
+		rcolor.green = data->color.green * data->opacity / 0xffff;
+		rcolor.blue = data->color.blue * data->opacity / 0xffff;
+		rcolor.alpha = data->opacity;
 		if (XftColorAllocValue(data->display, data->visual,
 				       data->colormap, &rcolor, &ftcolor)) {
 			XftDrawRect(data->draw, &ftcolor,
@@ -545,7 +523,6 @@ _vte_xft_set_text_font(struct _vte_draw *draw,
 		       const PangoFontDescription *fontdesc,
 		       VteTerminalAntiAlias antialias)
 {
-	GString *string;
 	XftFont *font;
 	XGlyphInfo extents;
 	struct _vte_xft_data *data;
@@ -565,7 +542,6 @@ _vte_xft_set_text_font(struct _vte_draw *draw,
 	draw->height = 1;
 	draw->ascent = 1;
 
-	string = g_string_new("");
 	n = width = height = 0;
 	/* Estimate a typical cell width by looking at single-width
 	 * characters. */
@@ -607,7 +583,6 @@ _vte_xft_set_text_font(struct _vte_draw *draw,
 			draw->width /= 2;
 		}
 	}
-	g_string_free(string, TRUE);
 
 #ifdef VTE_DEBUG
 	if (_vte_debug_on(VTE_DEBUG_MISC)) {
